@@ -49,11 +49,12 @@ outfl = 'spline.txt'
 cpoints = []
 points, spline= None, None
 
-pic = Picture("https://embryology.med.unsw.edu.au/embryology/images/4/40/Mouse-_embryo_E11.5.jpg")
-pic.alpha(1).pickable(True)  # VTK9 has problems with opacity
+pic = Picture("https://embryology.med.unsw.edu.au/embryology/images/4/40/Mouse-_embryo_E11.5.jpg",
+              channels=[0,1,2]) # keep rgb but drop alpha channel
 
 t = """Click to add a point
 Right-click to remove
+Drag mouse to change constrast
 Press c to clear points
 Press s to save to file"""
 instrucs = Text2D(t, pos='bottom-left', c='white', bg='green', font='Quikhand', s=0.9)
@@ -62,6 +63,6 @@ plt = Plotter()
 plt.addCallback('KeyPress', keyfunc)
 plt.addCallback('LeftButtonPress', onLeftClick)
 plt.addCallback('RightButtonPress', onRightClick)
-plt.show(pic, instrucs, axes=True, bg='blackboard').close()
+plt.show(pic, instrucs, axes=True, bg='blackboard', mode='image').close()
 
 
