@@ -24,4 +24,4 @@ vects  = domain.getPointArray('U')/200
 arrows = Arrows(coords-vects, coords+vects, c='jet_r') # use colormap
 box    = domain.box().c('k') # build a box frame of the domain
 
-show(stream, arrows, box, probe, __doc__, axes=5)
+show(stream, arrows, box, probe, __doc__, axes=5).close()
