@@ -46,6 +46,7 @@ class Base3DProp(object):
         self.transform = None
         self._set2actcam = False # used by mesh.followCamera()
 
+
     def address(self):
         """
         Return a unique memory address integer which can serve as the ID of the
@@ -562,6 +563,10 @@ class Base3DProp(object):
         return m
 
     def printInfo(self):
+        """Obsolete, use print() instead."""
+        return self.print()
+
+    def print(self):
         """Print information about an object."""
         utils.printInfo(self)
         return self
@@ -775,7 +780,9 @@ class BaseActor(Base3DProp):
 
 
     def lighting(self, style='', ambient=None, diffuse=None,
-                 specular=None, specularPower=None, specularColor=None):
+                 specular=None, specularPower=None, specularColor=None,
+                 metallicity=None, roughness=None,
+        ):
         """
         Set the ambient, diffuse, specular and specularPower lighting constants.
 
@@ -839,6 +846,14 @@ class BaseActor(Base3DProp):
         if specular is not None: pr.SetSpecular(specular)
         if specularPower is not None: pr.SetSpecularPower(specularPower)
         if specularColor is not None: pr.SetSpecularColor(colors.getColor(specularColor))
+        if utils.vtkVersionIsAtLeast(9):
+            if metallicity is not None:
+                pr.SetInterpolationToPBR()
+                pr.SetMetallic(metallicity)
+            if roughness is not None:
+                pr.SetInterpolationToPBR()
+                pr.SetRoughness(roughness)
+
         return self
 
 
@@ -1379,10 +1394,20 @@ class BaseGrid(BaseActor):
             sf.Update()
             gf.SetInputData(sf.GetOutput())
             gf.Update()
+            poly = gf.GetOutput()
+            if shrink==1.0:
+                cleanPolyData = vtk.vtkCleanPolyData()
+                cleanPolyData.PointMergingOn()
+                cleanPolyData.ConvertLinesToPointsOn()
+                cleanPolyData.ConvertPolysToLinesOn()
+                cleanPolyData.ConvertStripsToPolysOn()
+                cleanPolyData.SetInputData(poly)
+                cleanPolyData.Update()
+                poly = cleanPolyData.GetOutput()
         else:
             gf.SetInputData(self._data)
             gf.Update()
-        poly = gf.GetOutput()
+            poly = gf.GetOutput()
 
         msh = vedo.mesh.Mesh(poly).flat()
         msh.scalarbar = self.scalarbar
@@ -1423,7 +1448,7 @@ class BaseGrid(BaseActor):
         return conn
 
 
-    def color(self, col, alpha=None):
+    def color(self, col, alpha=None, vmin=None, vmax=None):
         """
         Assign a color or a set of colors along the range of the scalar value.
         A single constant color can also be assigned.
@@ -1433,14 +1458,20 @@ class BaseGrid(BaseActor):
         and you want -3 to show red and 1.5 violet and 6 green, then just set:
 
         ``volume.color(['red', 'violet', 'green'])``
+        
+        :param list alpha: use a list to specify transparencies along the scalar range
+        :param float vmin: force the min of the scalar range to be this value
+        :param float vmax: force the max of the scalar range to be this value
         """
-        # superseeded in Points, Mesh
-
-        smin, smax = self._data.GetScalarRange()
+        # superseeds method in Points, Mesh
+        if vmin is None: 
+            vmin, _ = self._data.GetScalarRange()
+        if vmax is None: 
+            _, vmax = self._data.GetScalarRange()
         ctf = self.GetProperty().GetRGBTransferFunction()
         ctf.RemoveAllPoints()
         self._color = col
-
+        
         if utils.isSequence(col):
             if utils.isSequence(col[0]) and len(col[0])==2:
                 # user passing [(value1, color1), ...]
@@ -1454,29 +1485,29 @@ class BaseGrid(BaseActor):
                 # user passing [color1, color2, ..]
                 for i, ci in enumerate(col):
                     r, g, b = colors.getColor(ci)
-                    x = smin + (smax - smin) * i / (len(col) - 1)
+                    x = vmin + (vmax - vmin) * i / (len(col) - 1)
                     ctf.AddRGBPoint(x, r, g, b)
         elif isinstance(col, str):
             if col in colors.colors.keys() or col in colors.color_nicks.keys():
                 r, g, b = colors.getColor(col)
-                ctf.AddRGBPoint(smin, r,g,b) # constant color
-                ctf.AddRGBPoint(smax, r,g,b)
+                ctf.AddRGBPoint(vmin, r,g,b) # constant color
+                ctf.AddRGBPoint(vmax, r,g,b)
             else: # assume it's a colormap
-                for x in np.linspace(smin, smax, num=64, endpoint=True):
-                    r,g,b = colors.colorMap(x, name=col, vmin=smin, vmax=smax)
+                for x in np.linspace(vmin, vmax, num=64, endpoint=True):
+                    r,g,b = colors.colorMap(x, name=col, vmin=vmin, vmax=vmax)
                     ctf.AddRGBPoint(x, r, g, b)
         elif isinstance(col, int):
             r, g, b = colors.getColor(col)
-            ctf.AddRGBPoint(smin, r,g,b) # constant color
-            ctf.AddRGBPoint(smax, r,g,b)
+            ctf.AddRGBPoint(vmin, r,g,b) # constant color
+            ctf.AddRGBPoint(vmax, r,g,b)
         else:
             colors.printc("color(): unknown input type:", col, c='r')
 
         if alpha is not None:
-            self.alpha(alpha)
+            self.alpha(alpha, vmin=vmin, vmax=vmax)
         return self
 
-    def alpha(self, alpha):
+    def alpha(self, alpha, vmin=None, vmax=None):
         """
         Assign a set of tranparencies along the range of the scalar value.
         A single constant value can also be assigned.
@@ -1491,7 +1522,10 @@ class BaseGrid(BaseActor):
         Then all cells below -5 will be completely transparent, cells with a scalar value of 35
         will get an opacity of 40% and above 123 alpha is set to 90%.
         """
-        smin, smax = self._data.GetScalarRange()
+        if vmin is None: 
+            vmin, _ = self._data.GetScalarRange()
+        if vmax is None: 
+            _, vmax = self._data.GetScalarRange()
         otf = self.GetProperty().GetScalarOpacity()
         otf.RemoveAllPoints()
         self._alpha = alpha
@@ -1500,21 +1534,21 @@ class BaseGrid(BaseActor):
             alpha = np.array(alpha)
             if len(alpha.shape)==1: # user passing a flat list e.g. (0.0, 0.3, 0.9, 1)
                 for i, al in enumerate(alpha):
-                    xalpha = smin + (smax - smin) * i / (len(alpha) - 1)
+                    xalpha = vmin + (vmax - vmin) * i / (len(alpha) - 1)
                     # Create transfer mapping scalar value to opacity
                     otf.AddPoint(xalpha, al)
                     #colors.printc("alpha at", round(xalpha, 1), "\tset to", al)
             elif len(alpha.shape)==2: # user passing [(x0,alpha0), ...]
-                otf.AddPoint(smin, alpha[0][1])
+                otf.AddPoint(vmin, alpha[0][1])
                 for xalpha, al in alpha:
                     # Create transfer mapping scalar value to opacity
                     otf.AddPoint(xalpha, al)
-                otf.AddPoint(smax, alpha[-1][1])
+                otf.AddPoint(vmax, alpha[-1][1])
 
         else:
 
-            otf.AddPoint(smin, alpha) # constant alpha
-            otf.AddPoint(smax, alpha)
+            otf.AddPoint(vmin, alpha) # constant alpha
+            otf.AddPoint(vmax, alpha)
 
         return self
 
@@ -1657,7 +1691,7 @@ class BaseGrid(BaseActor):
         return self._update(cout)
 
 
-    def cutWithBoundingBox(self, box):
+    def cutWithBox(self, box):
         """
         Cut the grid with the specified bounding box.
 
@@ -1669,7 +1703,7 @@ class BaseGrid(BaseActor):
             .. code-block:: python
 
                 from vedo import *
-                tetmesh = TetMesh(datadir+'limb_ugrid.vtk')
+                tetmesh = TetMesh(dataurl+'limb_ugrid.vtk')
                 tetmesh.color('rainbow')
                 cu = Cube(side=500).x(500) # any Mesh works
                 tetmesh.cutWithBox(cu).show(axes=1)
@@ -1739,15 +1773,6 @@ class BaseGrid(BaseActor):
         If tetsOnly=True will cull all 1D and 2D cells from the output.
 
         Return a TetMesh.
-
-        Example:
-
-            .. code-block:: python
-
-                from vedo import *
-                ug = loadUnStructuredGrid(datadir+'ugrid.vtk')
-                tmesh = tetralize(ug)
-                tmesh.write('ugrid.vtu').show(axes=1)
         """
         return vedo.tetmesh.tetralize(self._data, tetsOnly)
 
