@@ -9,7 +9,7 @@ import vedo.docs as docs
 from vedo.colors import printc
 
 import vedo.settings as settings
-from vedo.settings import datadir, dataurl, embedWindow
+from vedo.settings import dataurl, embedWindow
 
 from vedo.mesh import Mesh
 
@@ -19,7 +19,7 @@ import vedo.shapes as shapes
 from vedo.shapes import Text3D, Text2D, Latex
 
 from vedo.plotter import show, clear, Plotter
-from vedo.plotter import closeWindow, closePlotter, interactive
+from vedo.plotter import interactive
 
 from vedo.pyplot import histogram
 
@@ -37,10 +37,9 @@ Basic example:
     .. code-block:: python
 
         import dolfin
-        from vedo.dolfin import dataurl, plot
-
-        mesh = dolfin.Mesh(dataurl+"dolfin_fine.xml")
-
+        from vedo.dolfin import dataurl, download, plot
+        fname = download(dataurl+"dolfin_fine.xml")
+        mesh = dolfin.Mesh(fname)
         plot(mesh)
 
     |dolfinmesh|
@@ -113,13 +112,10 @@ __all__ = [
     "Text3D",
     "Text2D",
     "Latex",
-    "datadir",
     "dataurl",
     "screenshot",
     "Video",
     "exportWindow",
-    "closeWindow",
-    "closePlotter",
     "interactive",
     "embedWindow",
 ]
