@@ -1,25 +1,22 @@
-import os
 import numpy as np
 import vtk
 import vedo
 import vedo.colors as colors
-import vedo.docs as docs
 import vedo.utils as utils
-import vedo.settings as settings
 from vtk.util.numpy_support import numpy_to_vtk
 
 __doc__ = (
     """
 Submodule extending the ``vtkImageActor`` object functionality.
 """
-    + docs._defs
+    + vedo.docs._defs
 )
 
 __all__ = ["Picture"]
 
 
 #################################################
-class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
+class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):   
     """
     Derived class of ``vtkImageActor``. Used to represent 2D pictures.
     Can be instantiated with a path file name or with a numpy array.
@@ -27,8 +24,11 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
     Use `Picture.shape` to access the number of pixels in x and y.
 
     |rotateImage| |rotateImage.py|_
-    """
-    def __init__(self, obj=None):
+    
+    :param list channels: only select these specific rgba channels (useful to remove alpha)
+    :param bool flip: flip xy axis convention (when input is a numpy array)
+    """    
+    def __init__(self, obj=None, channels=(), flip=False):
         vtk.vtkImageActor.__init__(self)
         vedo.base.Base3DProp.__init__(self)
 
@@ -40,8 +40,10 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
                 iac = vtk.vtkImageAppendComponents()
                 nchan = obj.shape[2] # get number of channels in inputimage (L/LA/RGB/RGBA)
                 for i in range(nchan):
-                    #arr = np.flip(np.flip(array[:,:,i], 0), 0).ravel()
-                    arr = np.flip(obj[:,:,i], 0).ravel()
+                    if flip:
+                        arr = np.flip(np.flip(obj[:,:,i], 0), 0).ravel()
+                    else:
+                        arr = np.flip(obj[:,:,i], 0).ravel()
                     varb = numpy_to_vtk(arr, deep=True, array_type=vtk.VTK_UNSIGNED_CHAR)
                     varb.SetName("RGBA")
                     imgb = vtk.vtkImageData()
@@ -52,7 +54,10 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
                 img = iac.GetOutput()
 
             elif len(obj.shape) == 2: # black and white
-                arr = np.flip(obj[:,:], 0).ravel()
+                if flip:
+                    arr = np.flip(obj[:,:], 0).ravel()
+                else:
+                    arr = obj.ravel()
                 varb = numpy_to_vtk(arr, deep=True, array_type=vtk.VTK_UNSIGNED_CHAR)
                 varb.SetName("RGBA")
                 img = vtk.vtkImageData()
@@ -85,6 +90,20 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         else:
             img = vtk.vtkImageData()
 
+        # select channels
+        nchans = len(channels)
+        if nchans and img.GetPointData().GetScalars().GetNumberOfComponents() > nchans:
+            pec = vtk.vtkImageExtractComponents()
+            pec.SetInputData(img)
+            if nchans == 3:
+                pec.SetComponents(channels[0], channels[1], channels[2])
+            elif nchans == 2:
+                pec.SetComponents(channels[0], channels[1])
+            elif nchans == 1:
+                pec.SetComponents(channels[0])
+            pec.Update()
+            img = pec.GetOutput()
+
         self._data = img
         self.SetInputData(img)
 
@@ -97,6 +116,10 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
     def inputdata(self):
         """Return the underlying ``vtkImagaData`` object."""
         return self._data
+    
+    def dimensions(self):
+        nx, ny, _ = self._data.GetDimensions()
+        return np.array([nx, ny])
 
     def _update(self, data):
         """Overwrite the Picture data mesh with a new data."""
@@ -128,13 +151,13 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
                    font="Theemim",
                    dpi=500,
                    justify="bottom-left",
-                   ):
+        ):
         """Build an image from a string."""
 
         if c is None: # automatic black or white
-            if settings.plotter_instance and settings.plotter_instance.renderer:
+            if vedo.settings.plotter_instance and vedo.settings.plotter_instance.renderer:
                 c = (0.9, 0.9, 0.9)
-                if np.sum(settings.plotter_instance.renderer.GetBackground()) > 1.5:
+                if np.sum(vedo.settings.plotter_instance.renderer.GetBackground()) > 1.5:
                     c = (0.1, 0.1, 0.1)
             else:
                 c = (0.3, 0.3, 0.3)
@@ -163,14 +186,7 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         elif font.lower() == "arial": tp.SetFontFamilyToArial()
         else:
             tp.SetFontFamily(vtk.VTK_FONT_FILE)
-            if font in settings.fonts:
-                tp.SetFontFile(settings.fonts_path + font + '.ttf')
-            elif os.path.exists(font):
-                tp.SetFontFile(font)
-            else:
-                colors.printc("\sad Font", font, "not found in", settings.fonts_path, c="r")
-                colors.printc("\pin Available fonts are:", settings.fonts, c="m")
-                return None
+            tp.SetFontFile(utils.getFontPath(font))
 
         if bg:
             bgcol = colors.getColor(bg)
@@ -207,30 +223,96 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         else:
             return self.GetProperty().GetOpacity()
 
-    def crop(self, top=None, bottom=None, right=None, left=None):
+    def level(self, value=None):
+        """Get/Set the image color level (brightness)."""
+        if value is None:
+            return self.GetProperty().GetColorLevel()
+        self.GetProperty().SetColorLevel(value)
+        return self
+
+    def window(self, value=None):
+        """Get/Set the image color window (contrast)."""
+        if value is None:
+            return self.GetProperty().GetColorWindow()
+        self.GetProperty().SetColorWindow(value)
+        return self
+
+
+    def crop(self, top=None, bottom=None, right=None, left=None, pixels=False):
         """Crop picture.
 
         :param float top: fraction to crop from the top margin
         :param float bottom: fraction to crop from the bottom margin
         :param float left: fraction to crop from the left margin
         :param float right: fraction to crop from the right margin
+        :param bool pixels: units are pixels
         """
         extractVOI = vtk.vtkExtractVOI()
         extractVOI.SetInputData(self._data)
         extractVOI.IncludeBoundaryOn()
 
         d = self.GetInput().GetDimensions()
-        bx0, bx1, by0, by1 = 0, d[0]-1, 0, d[1]-1
-        if left is not None:   bx0 = int((d[0]-1)*left)
-        if right is not None:  bx1 = int((d[0]-1)*(1-right))
-        if bottom is not None: by0 = int((d[1]-1)*bottom)
-        if top is not None:    by1 = int((d[1]-1)*(1-top))
-        extractVOI.SetVOI(bx0, bx1, by0, by1, 0, 0)
+        if pixels:
+            extractVOI.SetVOI(right, d[0]-left, bottom, d[1]-top, 0, 0)
+        else:
+            bx0, bx1, by0, by1 = 0, d[0]-1, 0, d[1]-1
+            if left is not None:   bx0 = int((d[0]-1)*left)
+            if right is not None:  bx1 = int((d[0]-1)*(1-right))
+            if bottom is not None: by0 = int((d[1]-1)*bottom)
+            if top is not None:    by1 = int((d[1]-1)*(1-top))
+            extractVOI.SetVOI(bx0, bx1, by0, by1, 0, 0)
         extractVOI.Update()
         return self._update(extractVOI.GetOutput())
 
+    def pad(self, pixels=10, value=255):
+        """
+        Add the specified number of pixels at the picture borders.
+
+        Parameters
+        ----------
+        pixels : int,list , optional
+            number of pixels to be added (or a list of length 4). The default is 10.
+        value : int, optional
+            intensity value (gray-scale color) of the padding. The default is 255.
+        """
+        x0,x1,y0,y1,_z0,_z1 = self._data.GetExtent()
+        pf = vtk.vtkImageConstantPad()
+        pf.SetInputData(self._data)
+        pf.SetConstant(value)
+        if utils.isSequence(pixels):
+            pf.SetOutputWholeExtent(x0-pixels[0],x1+pixels[1],
+                                    y0-pixels[2],y1+pixels[4], 0,0)
+        else:
+            pf.SetOutputWholeExtent(x0-pixels,x1+pixels, y0-pixels,y1+pixels, 0,0)
+        pf.Update()
+        img = pf.GetOutput()
+        return self._update(img)
+
+
+    def tiling(self, nx=4, ny=4, shift=(0,0)):
+        """
+        Generate a tiling from the current picture by mirroring and repeating it.
+
+        Parameters
+        ----------
+        nx :  float, optional
+            number of repeats along x. The default is 4.
+        ny : float, optional
+            number of repeats along x. The default is 4.
+        shift : list, optional
+            shift in x and y in pixels. The default is 4.
+        """
+        x0,x1,y0,y1,z0,z1 = self._data.GetExtent()
+        constantPad = vtk.vtkImageMirrorPad()
+        constantPad.SetInputData(self._data)
+        constantPad.SetOutputWholeExtent(int(x0+shift[0]+0.5), int(x1*nx+shift[0]+0.5),
+                                         int(y0+shift[1]+0.5), int(y1*ny+shift[1]+0.5), z0,z1)
+        constantPad.Update()
+        return Picture(constantPad.GetOutput())
+
+
     def resize(self, newsize):
-        """Resize the image by specifying the number of pixels in width and height.
+        """Resize the image resolution by specifying the number of pixels in width and height.
         If left to zero, it will be automatically calculated to keep the original aspect ratio.
 
         :param list newsize: shape of picture as [npx, npy]
@@ -263,19 +345,126 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         elif axis.lower() == "y":
             ff.SetFilteredAxis(1)
         else:
-            colors.printc("\times Error in mirror(): mirror must be set to x or y.", c='r')
+            colors.printc("Error in mirror(): mirror must be set to x or y.", c='r')
             raise RuntimeError()
         ff.Update()
         return self._update(ff.GetOutput())
+        
+    def rotateAntiClockWise(self, n=1):
+        """
+        Rotate a black and white Picture in steps of 90 degrees anticlockwise 
+        (landscape to portrait and viceversa).
 
-    def extract(self, component):
-        """Extract one component of the rgb image"""
+        Parameters
+        ----------
+        n : int, optional
+            number of 90 deg rotations. The default is 1.
+        """
+        nx,ny,nz = self._data.GetDimensions()
+        n = n%4
+        if n==1:
+            self.bw()
+            varr = self._data.GetPointData().GetScalars()
+            arr = utils.vtk2numpy(varr).reshape(nx,ny, order='F')
+            pp = Picture(arr).mirror('x')
+            img = pp._data
+            pp = None
+            return self._update(img)
+        elif n==2:
+            return self.mirror('x').mirror('y')
+        elif n==3:
+            self.bw()
+            varr = self._data.GetPointData().GetScalars()
+            arr = utils.vtk2numpy(varr).reshape(nx,ny, order='F')
+            pp = Picture(arr).mirror('y')
+            img = pp._data
+            pp = None
+            return self._update(img)
+        else:
+            return self
+
+    # def rotateACW(self, n=1):
+    #     """
+    #     Rotate a black and white Picture in steps of 90 degrees anticlockwise 
+    #     (landscape to portrait and viceversa).
+
+    #     Parameters
+    #     ----------
+    #     n : int, optional
+    #         number of 90 deg rotations. The default is 1.
+    #     """
+    #     irs = vtk.vtkImageResize()
+    #     irs.SetResizeMethodToOutputDimensions()
+    #     nx,ny,nz = self._data.GetDimensions()
+    #     irs.SetOutputDimensions(ny, int(nx/2), 1)
+    #     irs.SetInputData(self._data)
+    #     irs.Update()
+    #     return self._update(irs.GetOutput())
+       
+        
+    def select(self, component):
+        """Select one single component of the rgb image"""
         ec = vtk.vtkImageExtractComponents()
         ec.SetInputData(self._data)
         ec.SetComponents(component)
         ec.Update()
         return Picture(ec.GetOutput())
+    
+    def bw(self):
+        """Make it black and white"""
+        n = self._data.GetPointData().GetNumberOfComponents()        
+        if n==4:
+            ecr = vtk.vtkImageExtractComponents()
+            ecr.SetInputData(self._data)
+            ecr.SetComponents(0,1,2)
+            ecr.Update()
+            img = ecr.GetOutput()
+        else:
+            img = self._data
+        
+        ecr = vtk.vtkImageLuminance()
+        ecr.SetInputData(img)
+        ecr.Update()
+        return self._update(ecr.GetOutput())
 
+    def smooth(self, sigma=3, radius=None):
+        """
+        Smooth a Picture with Gaussian kernel.
+
+        Parameters
+        ----------
+        sigma : int, optional
+            number of sigmas in pixel units. The default is 3.
+        radius : TYPE, optional
+            how far out the gaussian kernel will go before being clamped to zero. The default is None.
+        """
+        gsf = vtk.vtkImageGaussianSmooth()
+        gsf.SetDimensionality(2)
+        gsf.SetInputData(self._data)
+        if radius is not None:
+            if utils.isSequence(radius):
+                gsf.SetRadiusFactors(radius[0],radius[1])
+            else:
+                gsf.SetRadiusFactor(radius)
+        
+        if utils.isSequence(sigma):
+            gsf.SetStandardDeviations(sigma[0], sigma[1])
+        else:
+            gsf.SetStandardDeviation(sigma)
+        gsf.Update()
+        return self._update(gsf.GetOutput())
+
+    def median(self):
+        """Median filter that preserves thin lines and corners. 
+        It operates on a 5x5 pixel neighborhood. It computes two values initially: 
+        the median of the + neighbors and the median of the x neighbors. 
+        It then computes the median of these two values plus the center pixel. 
+        This result of this second median is the output pixel value.
+        """
+        medf = vtk.vtkImageHybridMedian2D()
+        medf.SetInputData(self._data)
+        medf.Update()        
+        return self._update(medf.GetOutput())
 
     def fft(self, mode='magnitude', logscale=12, center=True):
         """Fast Fourier transform of a picture.
@@ -363,7 +552,61 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
 
         return Picture(out)
 
+    def frequencyPassFilter(self, lowcutoff=None, highcutoff=None, order=3):
+        """
+        Low-pass and high-pass filtering become trivial in the frequency domain.
+        A portion of the pixels/voxels are simply masked or attenuated.
+        This function applies a high pass Butterworth filter that attenuates the
+        frequency domain image with the function
 
+        |G_Of_Omega|
+
+        The gradual attenuation of the filter is important.
+        A simple high-pass filter would simply mask a set of pixels in the frequency domain,
+        but the abrupt transition would cause a ringing effect in the spatial domain.
+
+        :param list lowcutoff:  the cutoff frequencies
+        :param list highcutoff: the cutoff frequencies
+        :param int order: order determines sharpness of the cutoff curve
+        """
+        #https://lorensen.github.io/VTKExamples/site/Cxx/ImageProcessing/IdealHighPass
+        fft = vtk.vtkImageFFT()
+        fft.SetInputData(self._data)
+        fft.Update()
+        out = fft.GetOutput()
+
+        if highcutoff:
+            butterworthLowPass = vtk.vtkImageButterworthLowPass()
+            butterworthLowPass.SetInputData(out)
+            butterworthLowPass.SetCutOff(highcutoff)
+            butterworthLowPass.SetOrder(order)
+            butterworthLowPass.Update()
+            out = butterworthLowPass.GetOutput()
+
+        if lowcutoff:
+            butterworthHighPass = vtk.vtkImageButterworthHighPass()
+            butterworthHighPass.SetInputData(out)
+            butterworthHighPass.SetCutOff(lowcutoff)
+            butterworthHighPass.SetOrder(order)
+            butterworthHighPass.Update()
+            out = butterworthHighPass.GetOutput()
+
+        butterworthRfft = vtk.vtkImageRFFT()
+        butterworthRfft.SetInputData(out)
+        butterworthRfft.Update()
+
+        butterworthReal = vtk.vtkImageExtractComponents()
+        butterworthReal.SetInputData(butterworthRfft.GetOutput())
+        butterworthReal.SetComponents(0)
+        butterworthReal.Update()
+        
+        caster = vtk.vtkImageCast()
+        caster. SetOutputScalarTypeToUnsignedChar()
+        caster.SetInputData(butterworthReal.GetOutput())
+        caster.Update()
+        return self._update(caster.GetOutput())
+    
+    
     def blend(self, pic, alpha1=0.5, alpha2=0.5):
         """Take L, LA, RGB, or RGBA images as input and blends
         them according to the alpha values and/or the opacity setting for each input.
@@ -432,6 +675,29 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
         gr.inputdata().GetPointData().AddArray(self._data.GetPointData().GetScalars())
         return gr
 
+    def tonumpy(self):
+        """Get read-write access to pixels of a Picture object as a numpy array.
+        Note that the shape is (nrofchannels, nx, ny).
+
+        When you set values in the output image, you don't want numpy to reallocate the array
+        but instead set values in the existing array, so use the [:] operator.
+        Example: arr[:] = arr - 15
+
+        If the array is modified call:
+        ``picture.modified()``
+        when all your modifications are completed.
+        """
+        nx, ny, _ = self._data.GetDimensions()
+        nchan = self._data.GetPointData().GetScalars().GetNumberOfComponents()
+        narray = utils.vtk2numpy(self._data.GetPointData().GetScalars()).reshape(nchan, ny,nx)
+        # narray = np.transpose(narray, axes=[1, 0])
+        return narray
+    
+    def modified(self):
+        """Use in conjunction with ``tonumpy()`` to update any modifications to the picture array"""
+        self._data.GetPointData().GetScalars().Modified()
+        return self
+    
     def write(self, filename):
         """Write picture to file as png or jpg."""
         vedo.io.write(self._data, filename)
@@ -439,4 +705,3 @@ class Picture(vtk.vtkImageActor, vedo.base.Base3DProp):
 
 
 
-
