@@ -6,6 +6,7 @@ from vedo.colors import printc
 import time
 import math
 import sys
+import os
 
 __doc__ = (
     """
@@ -450,6 +451,29 @@ def buildPolyData(vertices, faces=None, lines=None, indexOffset=0, fast=True, te
     return poly
 
 ##############################################################################
+def getFontPath(font):
+    if font in vedo.settings.font_parameters.keys():
+        if vedo.settings.font_parameters[font]["islocal"]:
+            fl = os.path.join(vedo.settings.fonts_path, f'{font}.ttf')
+        else:
+            fl = vedo.io.download(f"https://vedo.embl.es/fonts/{font}.ttf", verbose=False)
+    else:
+        if font.startswith("https://"):
+            fl = vedo.io.download(font, verbose=False)
+        elif os.path.isfile(font):
+            fl = font # assume user is passing a valid file
+        else:
+            if font.endswith(".ttf"):
+                printc("Could not set font file", font,
+                       "-> Using default:", vedo.settings.defaultFont, c='r')
+            else:
+                printc("Could set font name", font,
+                       "-> Using default:", vedo.settings.defaultFont, c='r')
+                printc("Check https://vedo.embl.es/fonts for additional fonts", c='r')
+                printc("Type 'vedo -r fonts' to see available fonts", c='g')
+            fl = getFontPath(vedo.settings.defaultFont)
+    return fl
+
 def isSequence(arg):
     """Check if input is iterable."""
     if hasattr(arg, "strip"):
@@ -927,16 +951,16 @@ def printInfo(obj):
             printc(tab + "  diagonal size: ", c="g", bold=1, end="")
             printc(precision(actor.diagonalSize(), 6), c="g", bold=0)
 
-            if hasattr(actor, "area"):
-                _area = actor.area()
-                if _area:
-                    printc(tab + "           area: ", c="g", bold=1, end="")
-                    printc(precision(_area, 6), c="g", bold=0)
+            # if hasattr(actor, "area"):
+                # _area = actor.area()
+                # if _area:
+                #     printc(tab + "           area: ", c="g", bold=1, end="")
+                #     printc(precision(_area, 6), c="g", bold=0)
 
-                _vol = actor.volume()
-                if _vol:
-                    printc(tab + "         volume: ", c="g", bold=1, end="")
-                    printc(precision(_vol, 6), c="g", bold=0)
+                # _vol = actor.volume()
+                # if _vol:
+                #     printc(tab + "         volume: ", c="g", bold=1, end="")
+                #     printc(precision(_vol, 6), c="g", bold=0)
 
         printc(tab + "         bounds: ", c="g", bold=1, end="")
         bx1, bx2 = precision(bnds[0], 3), precision(bnds[1], 3)
@@ -1738,23 +1762,28 @@ def trimesh2vedo(inputobj, alphaPerCell=False):
     return None
 
 
-def vedo2meshlab(vmesh):
+def _vedo2meshlab(vmesh):
     try:
         import pymeshlab as mlab
     except RuntimeError:
         printc("Need pymeshlab to run: pip install pymeshlab", c='r')
 
-    ms = mlab.MeshSet()
     m = mlab.Mesh(vertex_matrix=vmesh.points(),
                   face_matrix=vmesh.faces(),
                   v_normals_matrix=vmesh.normals(cells=False, compute=False),
                   f_normals_matrix=vmesh.normals(cells=True, compute=False),
-                 )
+    )
+    parr = vmesh.getPointArray()
+    if parr is not None:
+        m.vertex_quality_array(parr)
+    carr = vmesh.getCellArray()
+    if carr is not None:
+        m.face_quality_array(carr)        
     m.update_bounding_box()
-    ms.add_mesh(m)
-    return ms
+    return m
 
-def meshlab2vedo(mmesh):
+
+def _meshlab2vedo(mmesh):
     inputtype = str(type(mmesh))
 
     if "MeshSet" in inputtype:
@@ -1762,10 +1791,37 @@ def meshlab2vedo(mmesh):
     mpoints, mcells = mmesh.vertex_matrix(), mmesh.face_matrix()
     pnorms = mmesh.vertex_normal_matrix()
     cnorms = mmesh.face_normal_matrix()
+        
+    try:
+        parr = mmesh.vertex_quality_array()
+    except:
+        parr = None
+    try:
+        carr = mmesh.face_quality_array()
+    except:
+        carr = None  
+    
     if len(mcells):
         polydata = buildPolyData(mpoints, mcells)
     else:
         polydata = buildPolyData(mpoints, None)
+    
+    if parr is not None:
+        parr_vtk = numpy_to_vtk(parr)
+        parr_vtk.SetName("MeshLabQuality")
+        x0,x1 = parr_vtk.GetRange()
+        if x1-x0:
+            polydata.GetPointData().AddArray(parr_vtk)
+            polydata.GetPointData().SetActiveScalars("MeshLabQuality")
+    
+    if carr is not None:
+        carr_vtk = numpy_to_vtk(carr)
+        carr_vtk.SetName("MeshLabQuality")
+        x0,x1 = carr_vtk.GetRange()
+        if x1-x0:
+            polydata.GetCellData().AddArray(carr_vtk)
+            polydata.GetCellData().SetActiveScalars("MeshLabQuality")
+        
     if len(pnorms):
         polydata.GetPointData().SetNormals(numpy2vtk(pnorms))
     if len(cnorms):
